## Version 0.5.4

This release includes several updates to the validation logic for commit messages, as well as new model names for llamabot.

### New Features

- The maximum allowed characters for commit message descriptions has been increased from 79 to 160. Scope descriptions can now contain up to two words instead of one, and the one line description limit has been updated back to 79 characters. Additionally, an emoji field has been added to the CommitMessage model and the commit message format has been modified to include emoji. (6dce0c9, Eric Ma)
- Three new model names have been added to llamabot: bge-large, paraphrase-multilingual, and bge-m3. (585537f, Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
